#!/bin/bash
#
# create_lake.sh
# Create RIM based data warehouse.
#

usage() {
    echo "USAGE: $0 <LAKEHOST> <LAKEPORT> <LAKEUSER> <LAKEDB> <ACTION>"
    echo "e.g.: $0 localhost 5432 xfmuser lake"
    exit 1
}

if [ $# -lt 5 ]; then
    usage
fi

LAKEHOST=$1;
LAKEPORT=$2;
LAKEUSER=$3;
LAKEDB=$4;

PSQL="psql --set=ON_ERROR_STOP=1 --log-file=/tmp/create_lake.log --host=${LAKEHOST} --port=${LAKEPORT} --user=${LAKEUSER}"
PGVERSION=$(/var/lib/xfm/getconfig.py /etc/xfm/xfm.json lake.pgversion | tr --delete .)

# Create lake database

${PSQL} --dbname=postgres --command="CREATE DATABASE ${LAKEDB}"

${PSQL} --dbname=${LAKEDB} <<EOF

    -- Create healthcare modules

    CREATE EXTENSION hl7basetable;
    CREATE EXTENSION ucum;
    CREATE EXTENSION hl7;
    CREATE EXTENSION hl7v3vocab_edition2011;
    ALTER DATABASE ${LAKEDB} SET search_path=public, hdl, hl7, r1, "\$user";
    CREATE EXTENSION hl7v3datatypes;

    -- Create RIM in schema rim2011

    CREATE SCHEMA rim2011;
    ALTER DATABASE ${LAKEDB} SET search_path=rim2011, public, hdl, hl7, r1, "\$user";
    CREATE EXTENSION hl7v3rim_edition2011;

    -- Create additional extensions

    CREATE EXTENSION tablefunc;
    CREATE EXTENSION pgcrypto;
    CREATE EXTENSION jsquery;

    -- Create RIM document store (JSON)

    \\i /opt/mgrid/xfm3-lake_${PGVERSION}/scripts/blobstore.sql;

    -- In PostgreSQL, foreign keys cannot refer to inheritance child relations, so
    -- we need to disable these checks.

    \\i /opt/mgrid/xfm3-lake_${PGVERSION}/scripts/rim_dropforeignkeys.sql;

EOF
