#!/bin/bash
#
# create_ponds.sh
# Create pond staging RIM databases.
#
set -e

usage() {
    echo "USAGE: $0 <PONDHOST> <PONDPORT> <PONDUSER> <PONDCOUNT>"
    echo "e.g.: $0 localhost 5433 xfmuser 1"
    exit 1
}

if [ $# -ne 4 ]; then
    usage
fi

PONDHOST=$1;
PONDPORT=$2;
PONDUSER=$3;
PONDCOUNT=$4;

TEMPLATEDB=pondtemplate
PSQL="psql --set=ON_ERROR_STOP=1 --log-file=/tmp/create_ponds.log --host=${PONDHOST} --port=${PONDPORT} --user=${PONDUSER}"
PGVERSION=$(/var/lib/xfm/getconfig.py /etc/xfm/xfm.json loader.pond.pgversion | tr --delete .)

# Create template database

${PSQL} --dbname=postgres <<EOF
    CREATE USER ${TEMPLATEDB};
    CREATE DATABASE ${TEMPLATEDB};
EOF

${PSQL} --dbname=${TEMPLATEDB} <<EOF

    -- Create healthcare modules

    CREATE EXTENSION hl7basetable;
    CREATE EXTENSION ucum;
    CREATE EXTENSION hl7;
    CREATE EXTENSION hl7v3vocab_edition2011;
    ALTER DATABASE ${TEMPLATEDB} SET search_path=public, hdl, hl7, r1, "\$user";
    CREATE EXTENSION hl7v3datatypes;
    CREATE EXTENSION snomedctvocab_20140131;
    CREATE EXTENSION loinc_2_50;

    -- Creating RIM in schema rim2011

    CREATE SCHEMA rim2011;
    ALTER DATABASE ${TEMPLATEDB} SET search_path=rim2011, public, hdl, hl7, r1, "\$user";
    CREATE EXTENSION hl7v3rim_edition2011;
    ALTER SEQUENCE "InfrastructureRoot__id_seq" CACHE 32;
    CREATE EXTENSION hl7v3crud_edition2011;

    -- Create pond functions

    \\i /opt/mgrid/xfm3-loader_${PGVERSION}/pond/stream.sql;
    \\i /opt/mgrid/xfm3-loader_${PGVERSION}/pond/pond.sql;

    -- In PostgreSQL, foreign keys cannot refer to inheritance child relations, so
    -- we need to disable these checks.

    \\i /opt/mgrid/xfm3-loader_${PGVERSION}/pond/rim_dropforeignkeys.sql;

    -- Restricting login to owner

    BEGIN;
        REVOKE connect ON DATABASE ${TEMPLATEDB} FROM public;
        GRANT connect ON DATABASE ${TEMPLATEDB} TO ${TEMPLATEDB};
    COMMIT;
EOF

# Create pond databases based on template database

for i in $(seq 1 ${PONDCOUNT}); do
    ${PSQL} --dbname=postgres --command="CREATE DATABASE pond${i} TEMPLATE ${TEMPLATEDB}"
    ${PSQL} --dbname=${TEMPLATEDB} --command="ALTER DATABASE pond${i} SET search_path=rim2011, public, hdl, hl7, r1, \"\$user\""
done
