#!/bin/bash
#
# pond_upload.sh
# Process and transfer a local data pond to the lake
#
set -o pipefail
set -e

usage() {
  cat << EOF
  usage: $0 [OPTIONS]

  Process and transfer a local data pond to the lake.

  OPTIONS:
     -h      Show this message
     -n      Pond database name
     -u      Pond database username
     -p      Pond port
     -H      Lake database host
     -N      Lake database name
     -U      Lake database username
     -P      Lake database port
EOF
}

source ${HOME}/.bashrc

PONDDB=pond1
PONDUSER=${USER}
PONDHOST=localhost
PONDPORT=5432
LAKEDB=lake
LAKEUSER=${USER}

while getopts "hn:u:p:H:N:U:P:" opt; do
        case $opt in
        h)
          usage
          exit 1
        ;;
        n)
          PONDDB=$OPTARG
        ;;
        u)
          PONDUSER=$OPTARG
        ;;
        p)
          PONDPORT=$OPTARG
        ;;
        H)
          LAKEHOST=$OPTARG
        ;;
        N)
          LAKEDB=$OPTARG
        ;;
        U)
          LAKEUSER=$OPTARG
        ;;
        P)
          LAKEPORT=$OPTARG
        ;;
        ?)
          exit 1
        ;;
        esac
done

PONDPSQL="psql --set=ON_ERROR_STOP=1 --host=${PONDHOST} --port=${PONDPORT} --user=${PONDUSER}"
PGVERSION=$(/var/lib/xfm/getconfig.py /etc/xfm/xfm.json loader.pond.pgversion | tr --delete .)

# Copy pond to lake

PGOPTIONS='--hdl.concept_print_mode=complex_r1' \
    pg_dump --data-only --no-owner --no-privileges --schema=rim2011 --dbname=${PONDDB} --user=${PONDUSER} --port=${PONDPORT} | sed \
        -e '/SET search_path/ s/;/, hl7, hdl, r1;/' \
        -e '/SET lock_timeout/d' \
        -e '/pg_catalog.setval/d' \
        -e '/SET row_security/d' | \
        psql --single-transaction --set=ON_ERROR_STOP=1 --host=${LAKEHOST} --port=${LAKEPORT} --user=${LAKEUSER} --dbname=${LAKEDB}

# Empty pond

${PONDPSQL} --dbname=${PONDDB} --command "SELECT pond_empty()"
